package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`"``!````X!T```````!```````````"X````
M````!P``@$``.``*`$``'@`=``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```#PI0``````
M`/"E````````\*4````````/``````````\``````````0`````````#``!P
M!````'`"````````<`(```````!P`@```````!@`````````&``````````(
M``````````$````%````````````````````````````````````!*8`````
M```$I@```````````0```````0````8````(I@````````BF`0``````"*8!
M``````!(#0```````'@=```````````!```````"````!````(@$````````
MB`0```````"(!````````'`"````````<`(````````(``````````0````$
M````0`0```````!`!````````$`$````````1`````````!$``````````0`
M````````4>5T9`<`````````````````````````````````````````````
M````````````$`````````!2Y71D!`````BF````````"*8!```````(I@$`
M`````/@)````````^`D````````!````````````````````````````````
M``````````````````````````````````````````@```````````!``@("
M``$```````````$``````````2@```````#V!P"R````````````````````
M```````P,`(```````$H````````````````````````````````````````
M,#`"```````!*````````````````````````````````````````#`P`@``
M`````2@````````$``"R```````````````````````````P,`(```````$H
M````````/``!L@``````````````````````````,#`"```````!*```````
M`/P/__(``````````````````````````#`P`@```````2@```````#\_W^S
M```````````````````````````P,`(```````$H````````<``_L@``````
M````````````````````,#`"```````!*````````(0``+(`````````````
M`````````````#`P`@```````2@`````````````````````````````````
M```````P,`(```````$H````````````L```````````````````````````
M,#`"```````$````%`````,```!'3E4`LE&2JQ%#:Y7@ZF'R^?DGHV'L;:D$
M````$`````$```!'3E4```````,````"```````````````!`````````"@#
M`````````0`````````X`P````````$`````````2`,````````!````````
M`%(#````````#`````````#8&@````````T`````````8&4````````9````
M``````BF`0``````&P`````````(`````````!H`````````$*8!```````<
M``````````@`````````!`````````#X!@````````4``````````!0`````
M```&`````````"@*````````"@````````#P!`````````L`````````&```
M```````U``!P`````+BJ`0``````%0````````````````````,`````````
M0+`!```````1`````````(@:````````$@````````!0`````````!,`````
M````$``````````!``!P``````$`````````!0``<``````"``````````8`
M`'`````````````````*``!P`````!P`````````$0``<`````!I````````
M`!(``'``````'0`````````3``!P`````"0`````````'@`````````(````
M`````/O__V\``````0``"`````#^__]O`````,@9````````____;P`````#
M`````````/#__V\`````\!@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!A````:0``````````````
M#0```"H``````````````#\``````````````"@```!*`````````$4```!+
M````(@````````!2````&@````,````L````"0```!$````[````+P``````
M````````4P```!4````N```````````````C````'0```#P`````````````
M`!8```!9`````````#0`````````,@````````!E````%````!(````F````
M`````&8````;````6@```$0```!0```````````````9````1@```#@```!#
M`````````````````````````$X`````````(0``````````````8````"<`
M````````+0```!<````I```````````````"````"@```#X```!C````'```
M`!`````S`````````"0````@```````````````3````&``````````]````
M'P```$`````E````,````#D`````````````````````````````````````
M````8@``````````````9`````````````````````````!-````80``````
M```,``````````````!!````!````$(`````````````````````````6P``
M`%8`````````````````````````#@```#4````Z`````````#$```!'````
M'@```"L``````````````%P```!H````7P```$P````W```````````````V
M````````````````````7@```$D````````````````````/``````````@`
M`````````````%T````+````2```````````````5P````````!4````````
M`````````````````$\```!1``````````````!5``````````````!8````
M`````&<```````````````4````````````````````'````````````````
M```````````````&````````````````````````````````````````````
M`````````````````````````P`,`-@:``````````````````!J`P``$@`-
M`'AA````````"``````````?!```$@`-`*`I````````&``````````!````
M$P#Q_P$```````````````````!A!```(``5``"P`0````````````````#Z
M`@``$0`````````````````````````P!```$@`-`$`U````````2```````
M```3!```$@`-`(!$````````;`$```````!+!```$``8`%"S`0``````````
M``````!2!```$@`-`&@L````````+`````````#]`P``$@`-`)@L````````
MH`$```````#P`P``$@`-`/`V````````8`H```````#.`P``$@`-`.!<````
M````Z`$```````!?!```$``5``"P`0````````````````#<`@``$0`0`)!E
M````````!`````````!L!```$``5``"P`0````````````````"0`P``$@`-
M`)@H````````!`$````````2````$0`6`#"P`0````````````````!:`P``
M$@`-`-!@````````J``````````)!```$0`5`""P`0``````"`````````!S
M!```$``9`(##`0````````````````#C`P``$@`-`#@N````````3`8`````
M``#9`P``$@`-`,A>``````````(```````!X!```$``9`%"S`0``````````
M``````"$!```$@`-`$`H````````6`````````!B`@``$@`-`"`;````````
MM`(```````",!```$@`-`.`=``````````````````"F`P``$@`-`+@I````
M````K`(```````"S`P``$@`-`(@U````````9`$```````#[`@``(0``````
M``````````````````"4!```$@`-`(@T````````N`````````"B!```$``-
M`"`;``````````````````"I!```$``9`%"S`0````````````````#%`P``
M$@`-`%A<````````B`````````!Z`P``$@`-`%!!````````,`,```````"0
M`@``$@```$!E``````````````````#8`0``$@```#!E````````````````
M```O`@``$@```"!E``````````````````"9`0``$@```!!E````````````
M``````"?`0``$@````!E``````````````````#\`@``$0``````````````
M```````````G`@``$@```/!D``````````````````"S````(```````````
M``````````````#N`0``$@```.!D``````````````````"L`@``$@```-!D
M``````````````````"J````$@```,!D``````````````````#-````$@``
M`+!D``````````````````"9````$@````````````````````````"E`@``
M$@```*!D``````````````````#\`0``$@```)!D``````````````````#<
M````$@```(!D``````````````````".````$@```'!D````````````````
M``#@`0``$@```&!D``````````````````#M````$@```%!D````````````
M``````"`````$@```$!D``````````````````">`@``$@```#!D````````
M``````````#'`0``$@```"!D``````````````````!M````$@``````````
M``````````````"*`@``$@```!!D```````````````````1`@``$@````!D
M``````````````````#Y````$@```/!C```````````````````$`0``$@``
M`.!C```````````````````9`0``$@```-!C``````````````````"S`0``
M$@```,!C``````````````````!5`@``$@```+!C``````````````````"]
M`@``$@```*!C``````````````````!>````$@```)!C````````````````
M``!.`@``$@```(!C``````````````````!_`@``$@```'!C````````````
M```````E`0``(@`````````````````````````T`0``$@```&!C````````
M``````````!0`0``$@```%!C``````````````````#K`@``$@```$!C````
M``````````````!$`0``$@```#!C```````````````````#`@``$@```"!C
M``````````````````"_`0``$@```!!C```````````````````$`P``$@``
M``!C``````````````````!3````$@```/!B``````````````````!7`0``
M$@```.!B``````````````````!G`@``$@```-!B``````````````````!E
M`0``$0````````````````````````!%````$@```,!B````````````````
M```8`@``$@```+!B``````````````````!R`0``$0``````````````````
M``````!'`@``$@```*!B``````````````````#5`@``$@```)!B````````
M``````````#$`@``$@```(!B```````````````````[````$@```'!B````
M```````````````L````$@```&!B``````````````````!&`@``$@```%!B
M``````````````````"$`@``$@```$!B```````````````````<````$@``
M```````````````````````6`P``$0````````````````````````"V`@``
M$@```#!B```````````````````X`@``$@```"!B``````````````````!`
M````$@```!!B```````````````````?`@``$@````!B````````````````
M``#S`@``$0````````````````````````!"!```$@```/!A````````````
M``````!]`0``(`````````````````````````"Z`0``$@```.!A````````
M``````````!P`@``(@`````````````````````````*`@``$@```-!A````
M```````````````_`@``$@```,!A````````````````````7T193D%-24-?
M3$E.2TE.1P!?7U),1%]-05``8F]O=%]$>6YA3&]A9&5R`'!E<FQ?8V]N<W1R
M=6-T`'!E<FQ?9G)E90!P97)L7V1E<W1R=6-T`'!E<FQ?86QL;V,`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`<&5R
M;%]P87)S90!097)L7V%T9F]R:U]L;V-K`'!E<FQ?<G5N`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`4&5R;%]S=E]S971P=FX`4&5R;%]N97=84U]F;&%G
M<P!097)L7VUG7W-E=`!097)L7VYE=UA3`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?9V5T7W-V`%]?9VUO;E]S=&%R=%]?`%!E<FQ?9W9?9F5T8VAP=@!0
M97)L7W-A9F5S>7-M86QL;V,`4&5R;%]S=E]S971P=@!03%]D;U]U;F1U;7``
M4$Q?=&AR7VME>0!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`8VQO<V4`
M<'1H<F5A9%]G971S<&5C:69I8P!O<&5N-C0`<F5A9`!L<V5E:S8T`%]?97)R
M;F]?;&]C871I;VX`;W!E;F1I<@!?7W-T<FYC<'E?8VAK`%]?9G!R:6YT9E]C
M:&L`86-C97-S`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M96UM;W9E
M`'-T<FYC;7``8VQO<V5D:7(`<W1R9'5P`'-T<G-T<@!L<W1A=#8T`'-T<F-H
M<@!?7VQI8F-?<W1A<G1?;6%I;@!R96%D;&EN:P!?7V-X85]F:6YA;&EZ90!E
M>&ET`')M9&ER`&UK9&ER`%]?<W!R:6YT9E]C:&L`;65M8VAR`'-T<G1O:P!R
M96%D9&ER-C0`;65M8W!Y`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL`&=E='5I
M9`!?24]?<W1D:6Y?=7-E9`!R96%L;&]C`'-T9&5R<@!?7V5N=FER;VX`7U]R
M96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU
M+C,T`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0N<V\N,0!?7VQI8F-?
M8W-U7VEN:70`7U]L:6)C7V-S=5]F:6YI`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V9I;F1P<F]G`'!A<E]S971U
M<%]L:6)P871H`'-H85]I;FET`'-H85]U<&1A=&4`<VAA7V9I;F%L`'!A<E]I
M;FET7V5N=@!P87)?;6MT;7!D:7(`<&%R7V1I<FYA;64`;7E?<&%R7W!L`'!A
M<E]C;&5A;G5P`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`7V5D871A`'!A<E]B87-E;F%M90!?7V1A=&%?<W1A<G0`7V9D
M871A`%]E;F0`7U]B<W-?<W1A<G0`>'-?:6YI=`!?7W-T87)T`'!A<E]E;G9?
M8VQE86X`7V9T97AT`%]F8G-S`$=,24)#7S(N-`!'3$E"0U\R+C(`1TQ)0D-?
M,BXP`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N,S,```````$`
M`0`!``$``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``@`!``$``0`!``$`"@`"``(`!``$``(``@`!``H``P`!``$`
M`0`"``(``0`!``H``0`!``(`!``!``(``@`!``$``0`)``(``@`!``(``@`!
M``$``@`"``$``@`)``@``0`!``(``0`!``(``0`&``(`!P`!``$`!@`"``$`
M!0`"``(``@`"``(``@`!``0``P`"``(``````````0`!`%(#```0````(```
M`!1I:0T```4`KP0````````!``(`.`,``!`````P````$FEI#0``"0"Y!```
M$````!!I:0T```0`PP0````````!``8`2`,``!``````````=!EI"0``"@#-
M!```$````'(9:0D```@`V00``!`````4:6D-```'`*\$```0````LY&6!@``
M!@#E!```$````!)I:0T```,`N00``!`````0:6D-```"`,,$````````````
M``````````````````BF`0``````````````$@,0I@$``````````````!(#
M(+`!```````````````2`TBS`0``````````````$@/P_[UG``"\_P(`'#PM
MX)D#"`"__U@5G&<`@H+?!`!`$```````@IG?"?@@`P`````(`+_?``"\WP@`
MX`,0`+UG``````````"0_[UG8`"\_P(`'#PMX)D#$!6<9S@`L?^X@I'?Z(&9
MWV@`O_]8`+7_4`"T_T@`L_]``++_,`"P_R48@````"+>$`"E_P@`IO\0`*5G
M"`"F9QP`I&<<`*.O*`"B_PGX(`,`````H(&&WU"!A-^P@)G?>Q$1!"4HP`!8
M@H+?``!"D&$`0!!`@IG?.("0WW""DM\0@9G?"?@@`P``1(X``$2.V@1#D!"!
MF=\"`&,T"?@@`]H$0Z`<`*:/V@1#D`0`Q"0@@IG?`0!C-/@@!``#`,8DV@1#
MH`GX(`,``*;_$`"EWR4X0``X@(+?N("#WW##1_Q0@(+?``"IW$AI0F0<`*B/
M"`#B_%"`@M\``&3<4&E"9`(``RD``*;?``#I_!``Y/Q<`&`4&`#B_`,`"24(
M`*5D`P`()00`!"0``*+<^!@$`"T8XP`!`(0D``!B_/K_!!4(`*5D)1`@`5"`
MA=]P@9G?>,,$WO@0`@`M$.(`)4```*`GI60)^"`#``!`_"\`0!`ED$``8(*9
MWWC#!-Y0@)/?"?@@`R0`M&=0@(3?8!]S9B4H@`(ER&`"I0`1!(!FA&0G`$`0
M.("5WY""F=\)^"`#>,,$WHB!F=\)^"`#`````"@`H]\``"+>,P!B%&@`O]]@
M`+S?6`"UWU``M-](`+/?.`"QWS``L-\E$$`"0`"RWP@`X`-P`+UG"?@@`SB`
MD-\E($``(0!`$'C#`OZ8@IG?"?@@`W""DM\0@9G?"?@@`P``1(Z6_P`0API`
MH$"!F=\)^"`#>,,$WL[_`!`ED$``:,.DW@4`@!#`@)G?P`D1!`````#5_P`0
MD(*9WU"`A-\E*(`")<A@`G$`$00(9H1D)2!``,S_0!!HPZ+^\_\`$,"`F=^P
M_P`0!``")/B!F=\)^"`#`0`$)(B"F=\)^"`#`````````````````````"4`
MX`,!`!$$`````"7(@`,"`!P\1!*<)RW@GP,E^```(("$WP``I=\(`*9G\/\!
M)"3HH0,H@(??,("(WR5(0``E4*`#V(&9WPGX(`,`````__\`$```````````
M``````(``SPM&'D`\!%C9#B`9-Q`@&+<.+"$9`4`1!#P@GG<`P`@$P`````(
M`"`#``````@`X`,``````@`#/"T8>0"X$6-D.(!DW$"`9=PXL(1D+RBD`/L0
M!0#^+P4`+2BB`'LH!0`%`*`0*(%YW`,`(!,`````"``@`P`````(`.`#````
M``````#@_[UG$`"\_P(`'#PMX)D#:!&<9P@`L/\X@)#?&`"__U"S`I(,`$`4
M`(."WP0`0!!(@(+?`(.9WPGX(`,``$3<4("9WT`>.6?+_Q$$``````$``B10
MLP*B&`"_WQ``O-\(`+#?"`#@`R``O6<``````@`"/"T060#X$$)D4(!9W'@>
M.6?*_P`0`````````````````````+#_O6=``+S_`@`</"W@F0-(`+__.`"V
M_S``M?\H`+3_(`"S_Q@`LO\0`+'_"`"P_T$`@!#0$)QG&(&"WP``5-P]`(`2
M):B`````@H`EF*``)9"``$4`0!`]``,D!`!#$``````!`$*"_/]`%`$`4F8O
MD%4"`)`2````D-X/```2)8B``CT`%B0@@9G?)2```B4P0`()^"`#)2B@`@0`
M0!0M&!("``!B@!$`5A``````"``PWO3_`!8(`#%F2`"_WT``O-\X`+;?,`"U
MWR@`M-\@`+/?&`"RWQ``L=\E$``""`"PWP@`X`-0`+UG`````"^(-`+[B!$`
M``!QKD@`O]\!`%)F+8`2`D``O-\X`+;?,`"UWR@`M-\@`+/?&`"RWQ``L=\E
M$``""`"PWP@`X`-0`+UG`````$@`O]\E@```0`"\WS@`MM\P`+7?*`"TWR``
ML]\8`++?$`"QWR40``((`+#?"`#@`U``O6?"_P`0)9````````#`_KUG,`&\
M_P(`'#PMX)D#6`^<9P`!LO^X@I+?.`&__R@!M_\@`;;_&`&U_Q`!M/\(`;/_
M^`"Q__``L/\``$+>Z`"B_P0`@!````````""@!$`0!0E@(``Z`"CWP``0MYM
M`&(4.`&_WS`!O-\H`;??(`&VWQ@!M=\0`;3?"`&SWP`!LM_X`+'?\`"PWP@`
MX`-``;UG`````/B`F=\)^"`#`````.S_0!`EB$``4("3WU"`E-^897-F$`"U
M9]@@E&8X@9G?"?@@`R4@(`)``$`0`(&9WQ,`0Y#2_V,D`@!@%!,`5F0!`,.2
M]O]@$#B!F=\3`$*0TO]")`4`0!0``````0#"DM+_0B0Y`$`0`````.S_0!`X
M@9G?X(&9WPGX(`,E(``"X(&9WR4@P`()^"`#);A```"X%P``$`(`(;CB`A""
MF=\)^"`#`@#D)O"`F=\E($``)4C``B5```(E.&`"__\&)`$`!20)^"`#"`"B
M_P@`I-]X@IG?"?@@`R4HH`+__P,D!@!B$`@`I-\P`**/`$`#)`#P0C`;`$,0
M)<B``FB"F=\)^"`#"`"D_P@`I-_0@IG?"?@@`P`````X@9G?"?@@`R4@(`+"
M_T`4`(&9WPGX(`,E("`"J(*9WPGX(`,E(``"G/\`$````````````@#"DK+_
M0!#@@9G?Q_\`$```````````??\1!`````#G_P`0"`"DWXB"F=\)^"`#````
M````````_[UG\`"\_P(`'#PMX)D#,`V<9^``L/^X@I#?Z`"Q_Z""F=_X`+__
M```"WB4HH`,EB(``V`"B_PGX(`,`````#P!`%"``HX\`0`0D`/!C,`0`9!`E
M*&```*`#-`D`HQ0`````8(&9WP(`!20)^"`#)2`@`@,``!`!`$(L`````"40
M``#8`*3?```#W@8`@Q3X`+_?\`"\W^@`L=_@`+#?"`#@`P`!O6>(@IG?"?@@
M`P``````````L.^]9T`0O/\"`!P\+>"9`W@,G&<X$+3_(!"Q_[B"E-\EB(``
M4("$WS`0L_\H$++_4(*9WT@0O_\8$+#_"`"S9P``@MXED*``_P\&)"4H8`*@
M981D"!"B_PGX(`,``````!`"`!H`0!C__U`D$!`#9BT8?0#X[V.`*P!@%```
M```5```2<(*"WY"!F=\E,``"+P`%)`GX(`,E(&`"#`!`$'""@M\0@9G?"?@@
M`P``1(Q(@9G?)3@``B4P8`(E*"`""?@@`R4@0``+```0`````'""@M\`````
M$(&9WPGX(`,``$2,2(*9WR4P0`(E*"`""?@@`R4@0``($*/?``""W@L`8A1(
M$+_?0!"\WS@0M-\P$+/?*!"RWR`0L=\8$+#?"`#@`U`0O6?7_P`0)8!``(B"
MF=\)^"`#``````````"@_[UG4`"\_P(`'#PMX)D#.`N<9R``LO^X@I+?&`"Q
M_Q``L/]8`+__2`"W_T``MO\X`+7_,`"T_R@`L_\E@*`````#@@``1=X]``(D
M)8B```@`I?\"`&(4X(&9WP$`$&8)^"`#)2```E"`F=\$`*5G)2`@`F`?.6=[
M_A$$)9A``%4`0!`EH$``X(&9WPGX(`,E($``*Q!3`$$`0!`$`+:/&(&5W_BP
M%@```"*")1@@`@8`0!0]``0D<P``$"48```!`&*``P!`$`$`8V3\_T04````
M`"\8<0``&`,`$(*9WP(`9&8M((,`"?@@`P``L]XMF'8"&P!`$```8OX``*/>
M```B@BT8=@```&7<`0`D9@``HJ`(`$`4/0`&)`D``!`E&*``````````@H`!
M`(1D)P!`$`$`8J`E&*``^O]&%`$`I60]``0D`0!B9```9*````."`0!"9`$`
M$&;\_V`4__]#H`@`H]\``$+>2P!B%%@`O]]0`+S?2`"WWT``MM\X`+7?,`"T
MWR@`L]\@`++?&`"QWQ``L-\(`.`#8`"]9P```H(!`)1F`0`09NW_0!#__X*B
M```"@@$`E&8!`!!F]_]`%/__@J+F_P`0`````-S_`!`E&*``&(&5WP``M]X`
M`.+>*@!`$"40X`(EH```"`!#W"4@@`((`$)D_/]@%`$`E"8#`(0D^"`$`#B`
M@M]@PT.,%`!@%!B"F=\0@IG?`0`#)`GX(`-@PT.LS?]`$"4@0`#8@IG?^+`4
M`"4PP`()^"`#)2C@`B4@0````*+^`0"")O@0`@`M(((```"`_)'_`!`$`+2O
M)2B```GX(`,E(.`")2!``+K_0!```*+^\_\`$/BP%`"5_P`0$(*9WQ``!"3=
M_P`0):```(B"F=\)^"`#`````.#_O6<0`+S_`@`</"W@F0.0")QG"`"P_W""
MD-\8`+__$(&9WPGX(`,```2.$(&9WPGX(`,```2.6("'WU"`A=^P@H;?N(&9
MW]BEYV2P9:5D"?@@`R4@0``0@9G?"?@@`P``!(Y0@(C?4("%WV"`AM]H@9G?
M0&D(925(```E.``!T&6E9`GX(`,E($``&`"_WQ``O-\(`+#?"`#@`R``O6?P
M_[UG``"\_P(`'#PMX)D#\`><9W""@M\(`+__$(&9WPGX(`,``$2,6("'WU"`
MA=^P@H;?N(&9W]BEYV2P9:5D"?@@`R4@0``(`+_?``"\WP@`X`,0`+UGH-^]
M9U`@O/\"`!P\+>"9`Y@'G&=`(++_N(*2WU@@O_\H@IG?2""S_S`@L/\X(+'_
M``!"WB`0LV<H(*+_"?@@`P````!0@(G?4("'W_"`F=\8`*1GZ&4I925`0`#P
M9>=D`1`&)`$`!20)^"`#"`"D_P@`I-]0@IG?`!`&)`GX(`,E*&`"`(`"`!D`
M``80@IG?`0`$)@GX(`,EB``""`!`$"4@0`#`@IG?)3```@GX(`,E*&`"+8A1
M`"4@0````""B*""CWP``0MX+`&(46""_WU`@O-]((+/?0""RWS@@L=\P(+#?
M)1"```@`X`-@(+UG\_\`$"4@``"(@IG?"?@@`P```````````@`#/"T8>0"0
M!F-D:(!YW+G_`!``````H.Z]9T@1O/\"`!P\+>"9`W@&G&<X$;;_$!&Q_[B"
MEM\EB(``4("9WU"`A-]8$;__*!&T_P@1L/]0$;[_0!&W_S`1M?\@$;/_&!&R
M_P``P]X(9H1D8!\Y9R6@H``<`*5G^!"C_U#]$00`````\(&9WR\`!20E("`"
M"?@@`R6`0``9`$`0X(&9WU"`A-]0@)G?)2@@`O@D.6>I_A$$&&:$9"40(`+X
M$*3?``##WGP`@Q18$;_?4!&^WT@1O-]`$;??.!&VWS`1M=\H$;3?(!&SWQ@1
MLM\0$;'?"!&PWP@`X`-@$;UG`````"4@(`()^"`#4("2W\B"F=\E((`""?@@
M`P"8`@!8@9G?*&9%9@GX(`,E($``W/]`$"6X0`!0@(+?4("4WP!F0F0(`*+_
M``#B@E"`E=\\`$`0,&:49@`````&```2"(.9WR4HX`()^"`#)2```BP`0!!8
M@9G?X(&9WPGX(`,E(.`"+P`%)``0`@#__T,D+2#C`@``AH`)`,44+P`&)```
M```E$&``__]C)```@*`M(.,"``"%@/K_IA```````0!C)B$08@``$$(HM?]`
M$/"`F=_X`+YG)2#``R50(`(E2(`")4#@`CAFIV8`$`8D"?@@`P$`!21X@IG?
M(`"E9PGX(`,E(,`#!0!`%$``HH\`@`,T`/!",!@`0Q!@@9G?6(&9WRAF168)
M^"`#)2```)S_0!`EN$````#B@L?_0!0`````"0``$@````````*2TO]")`(`
M0!0``````0`"DO#_0!!8@9G?``````@`M]_3_P`0`0`")``````!``4D"?@@
M`R4@P`/F_T`46(&9WU"`A-]0@)G?)2C``_@D.6<N_A$$&&:$9,B"F=\)^"`#
M)2#``X+_`!``````B(*9WPGX(`,`````````````@X`'`&`0)1"````````!
M`(1D+P!E.```@X#\_V`4"A"%``@`X`,``````````.#_O6<0`+S_`@`</"W@
MF0,8`+__"`"Q_P``L/\Z`(`0F`.<9P``@H`W`$`0)8"``."!F=\)^"`#````
M`/__1F0M,`8"*Q`&`@4`0!0O``,D-P``$``````W``82````````PH#\_T,0
M___&9`$`QF0K$`8"+@!`$"\``R3__\9D+0`&$@```````,*`_/]#%/__QF0!
M`,9D!```$"\``R0``,*`!0!#%`````#__\9D*Q`&`OK_0!0`````+S#0``(`
MPF0!$$(L*0!`$#B`D=]X@9G?`!`')`$`QF0E*``""?@@`V"S)&9@LR)F&`"_
MWQ``O-\(`+'?``"PWP@`X`,@`+UG`````%"`A-_(@IG?"?@@`P!FA&08`+_?
M$`"\WP@`L=\``+#?"`#@`R``O6?>_P86+P`#)````X(O``(D$@!B$,B"F=]0
M@(3?"?@@`S!FA&08`+_?$`"\WP@`L=\``+#?"`#@`R``O6<`````&`"_WQ``
MO-\(`+'?``"PWR40```(`.`#(`"]9U"`A-\)^"`#`&:$9-7_`!`8`+_?8/^]
M9X@`O/\"`!P\+>"9`_@!G&=8@(/?8`"S_[B"D]^PI6)D:`"T_U@`LO]0`+'_
M2`"P_Y@`O_^0`+[_@`"W_W@`MO]P`+7_L*5FW`@`1=P0`$3<&`!#W```9]X@
M`$*44("0WU"`E-\8@9+?.`"G_Q``IO\8`*7_(`"D_R@`H_\P`**G#`"Q9V`?
M$&9`9I1F)2@@`B7(``(C_!$$)2"``A$`0!`,`*./``!"WO@8`P`M$$,`"`!#
MW/7_8!```$/\$`!#W`@`0F3]_V`4``!#_"4H(`(ER``"$_P1!"4@@`+Q_T`4
M#`"CCU"`E-\8@9+?4&:49B4H(`(ER``""OP1!"4@@`(2`$`0#`"CCP``0M[X
M&`,`+1!#``@`0]SU_V`0``!#_``````0`$/<"`!"9/W_8!0``$/\)2@@`B7(
M``+Y^Q$$)2"``O#_0!0,`*./4("4WQB!DM]89I1F)2@@`B7(``+P^Q$$)2"`
M`A(`0!`,`*./``!"WO@8`P`M$$,`"`!#W/7_8!```$/\`````!``0]P(`$)D
M_?]@%```0_PE*"`")<@``M_[$00E((`"\/]`%`P`HX]0@)3?&(&2WVAFE&8E
M*"`")<@``M;[$00E((`"$@!`$`P`HX\``$+>^!@#`"T00P`(`$/<]?]@$```
M0_P`````$`!#W`@`0F3]_V`4``!#_"4H(`(ER``"Q?L1!"4@@`+P_T`4#`"C
MCU"`E-\8@9+?<&:59B4H(`(ER``"O/L1!"4@H`(2`$`0#`"CCP``0M[X&`,`
M+1!#``@`0]SU_V`0``!#_``````0`$/<"`!"9/W_8!0``$/\)2@@`B7(``*K
M^Q$$)2"@`O#_0!0,`*./4("5WQB!DM^`9K5F)2@@`B7(``*B^Q$$)2"@`A(`
M0!`,`*./``!"WO@8`P`M$$,`"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@
M%```0_PE*"`")<@``I'[$00E(*`"\/]`%`P`HX]0@)7?&(&2WPAFMF8E*"`"
M)<@``HC[$00E(,`"$P!`$%"`E]\,`*./``!"WO@8`P`M$$,`"`!#W/3_8!``
M`$/\$`!#W`@`0F3]_V`4``!#_"4H(`(ER``"=_L1!"4@P`+Q_T`4#`"CCU"`
ME]\8@9+?D&;V9B4H(`(ER``";OL1!"4@P`(2`$`0#`"CCP``0M[X&`,`+1!#
M``@`0]SU_V`0``!#_``````0`$/<"`!"9/W_8!0``$/\)2@@`B7(``)=^Q$$
M)2#``O#_0!0,`*./4("6WQB!DM^@9MYF)2@@`B7(``)4^Q$$)2#``Q(`0!`,
M`*./``!"WO@8`P`M$$,`"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@%```
M0_PE*"`")<@``D/[$00E(,`#\/]`%`P`HX]0@)[?&(&2W[!FWF<E*"`")<@`
M`CK[$00E(,`#$@!`$`P`HX\``$+>^!@#`"T00P`(`$/<]?]@$```0_P`````
M$`!#W`@`0F3]_V`4``!#_"4H(`(ER``"*?L1!"4@P`/P_T`4#`"CCU"`GM\8
M@9+?&&;>9R4H(`(ER``"(/L1!"4@P`,2`$`0#`"CCP``0M[X&`,`+1!#``@`
M0]SU_V`0``!#_``````0`$/<"`!"9/W_8!0``$/\)2@@`B7(``(/^Q$$)2#`
M`_#_0!0,`*./4("$WR4H(`(ER``""/L1!,!FA&0P`$`0)2A``%"`DM_X)%)F
M)<A``F?\$02@9L1F4("$WR4H(`(ER``"_/H1!-AFA&0%`$`0)2A``%"`A-\E
MR$`"7/P1!/!FA&10@(3?)2@@`B7(``+Q^A$$`&>$9!P`0!`E*$``)<A``E+\
M$00(9J1F4("%WW!FA&8ER$`"3?P1!#AGI60X`*/?``!BWBD`8A28`+_?D`"^
MWX@`O-^``+??>`"VWW``M=]H`+3?8`"SWU@`LM]0`+'?2`"PWP@`X`.@`+UG
M4("2W]3_`!#X)%)F4("$WR4H(`(ER``"S_H1!!!GA&0&`$`0)2A``"7(0`(P
M_!$$D&;D9M[_`!!0@(7?4("%WR"!F=\*``8D*&>E9`GX(`,A`*1GU?]`%"L`
MI6<ER$`"(_P1!)!FY&;1_P`04("%WXB"F=\)^"`#``````````#0_[UG(`"\
M_P(`'#PMX)D#J/N<9Q@`L?\0`+#_.("1W[B"D-\H`+__```$WA"P(H[__P,D
M"`"D_PL`0Q!0@(3?"`"DWP```]X8`(,4*`"_WR``O-\8`+'?$`"PWP@`X`,P
M`+UG`````%"`F=\$`*5G8!\Y9YCZ$0209H1D"`!`$````````$*`!0!`$```
M```P`$(X*Q`"`.G_`!`0L"*N)1```.;_`!`0L"*NB(*9WPGX(`,`````\/^]
M9P``O/\"`!P\+>"9`_#ZG&>`@IG?"`"__PGX(`,`````Z(*9WPGX(`,E($``
M`@!`$`@`O]\``$+<``"\WP@`X`,0`+UGL/^]9T``O/\"`!P\+>"9`ZCZG&<P
M`+/_*`"R_U"`D]^X@I+?4("9WR``L?](`+__.`"T_Q@`L/\``$+>)8B```0`
MI6=`9V1F8!\Y9P@`HO]A^A$$`````!4`0!`E@$````!"@!(`0!`0@YG?)2@@
M`@GX(`,E(``"'0!`$."!F=\(`*/?``!"WC,`8A1(`+_?0`"\WS@`M-\P`+/?
M*`"RWR``L=\8`+#?"`#@`U``O6<(`*/?``!"WB<`8A0E*"`"4("9WT@`O]]`
M`+S?.`"TWR@`LM\@`+'?&`"PWT!G9&8P`+/?^"0Y9Z'[`!!0`+UG"?@@`R4@
M(`+@@9G?)2```@GX(`,EH$``$(*9WRT@@@()^"`#`@"$9%"`B=]0@(??\("9
MWP$`!20E4``"*&8I925`(`(X9N=D__\&)"4@0``)^"`#):!```@`H]\``$+>
MV_]B$"4H@`*(@IG?"?@@`P``````````$("]9]A_O/\"`!P\+>"9`T#YG&=0
M@(/?__\"/.!_OO_`?[7_N'^T_^A_O__0?[?_R'^V_[!_L_^H?[+_H'^Q_YA_
ML/]T?D5DX/V]9R6H@`"@@00T)3!@`"T@A0`0`*5G+2B%`+B"GM\(9L1DH($&
M-"TPP@`0`*)G+1#"`!``H_\0`*=G``##WYB!!C0M,,<```##_%"`@]]0@)3?
M`&9C9(!^0_Q0@(/?8!^49FAG8V2P?D/\4("#WR7(@`)P9V-DN'Y#_%"`@]^(
M?D#\>&=C9,!^0_Q0@(/?T'Y`_(!G8V3(?D/\4("#WZ!^0/R(9V-DW_D1!)A^
M0_P$`$`0@(*9WP``0X"``6`4)2!```GX(`,`````Z(*9WPGX(`,E($``00%`
M$/__$3P``%#<0`$`$G1^,F;@@9G?"?@@`R4@``(0@IG?>"`"``GX(`,!`(1D
M```(@@\``!$EB$``4("'WR60(`*89_-D\("9W_\`"#$E($`")3A@`O__!B0!
M``4D"?@@`P$`$&8```B"]O\`%0(`4F;__Q,\J'YV9J"!`C0M$%8`$`"C9W1^
M<V90@(3?4("2WRVP0P"@@0(T+1!3`/!FA&0`(U)F!```$"V80P`(`,3>9@"`
M$`@`UF8ER(`"H_D1!"4H8`+Y_T`0)8!`````0H#V_T`0)<A``H3Z$00E(``"
M\O]`$,B"F=\)^"`#)2```E8`0!`E@$```````."!F=\E(``""?@@`U"`D]_@
M@9G?)2`@`@GX(`,EL$```+`6```0`@`AL,("$(*9WP0$Q"8)^"`#);"``%"`
MBM]0@(??\("9WR4@0``E6"`"H&=*93!F:68E0``"J&?G9/__!B0!``4D"?@@
M`R600`"H@9G?P`$%)`GX(`,E($`"__\#)`<`8A28@9G?"?@@`P`````1``,D
M``!)C`<!(Q7@@H+?__\1/-A^)6:@@0(TH(*9WRT010`0`*-G+2A#``GX(`,E
M($`"10!`$"6`0`#@@H+?4("&WS"!F=\``*?>``!$W"5`0`+X9\9D`0`%)`GX
M(`,EB```$`"C9YB!`C0M$$,```!#W```PM_)`6(4)1`@`B`"O6?H?[_?X'^^
MW]A_O-_0?[??R'^VW\!_M=^X?[3?L'^SWZA_LM^8?[#?H'^QWP@`X`/P?[UG
M`````/__%CQ0@)#?H($"-"T05@`0`*-G8&<09B68```)```0+;!#```````M
M$,(">'Y0W!4``!(````````"@A(`0!``````)2```B7(0`(4^A$$`0!S)O3_
M0!#X$!,`R(*9WPGX(`,E(``"D?]`%"6`0`#X$!,`+1#"`GA^4-SN_P`6````
M``````")_P`0)8```*"!`C0M$%$`$`"C9RVX0P#X?N*.`$`#)`#P0C"U_T,4
MX(*"WX""F=\(?^.."?@@`Q@`H_\8`*/?`!`"`*W_8A3@@H+?^'[BCL`!`R3_
M`4(PJ/]#%.""@M\0@IG?"?@@`R4@P`)T?B5FH($#-"T890`0`*1G+2AD`%"`
MA-\ER(`"4&B$9/KX$00EB$``*@%`$"4H0`!P@)G?B_L1!```I-XE`4`0);A`
M`."!F=\)^"`#)2#@`@`8`@`$`&(H$`!`%"6P8`!0@(7?"(.9W_S_Q&98:*5D
M"?@@`RT@Y`((`$`4!``")"@!PA+[_\,F+1CC`@``8X`O``(D(P%B$``````X
M@)7?__\#)!"PHHX,`4,0__\%/(<`0!#0@9G?4("6WU"`@M]0@(7?D&;$9O@D
M660X9Z5D-/H1!!@`N?\H@IG?4("4WPGX(`/__Q4D4("'WT!IEV;P@)G?4("4
MWR58X`(E4$``,&9I9B5`0`)X:.=D__\&)`$`!20E("`""?@@`Q$`%B04```0
MB&B49@`````)^"`#````````0HP4`%84*(*9WPGX(`,!`!`F\("9WR58``(E
M4$``,&9I9B5`0`(E.(`"__\&)`$`!20E("`""?@@`P``M_^H@9G?P`$%)`GX
M(`,E("`"Z?^B$IB!F=_0@IG?"?@@`R4@0`(0`*+?&`"YWPAF1&0)^"`#)2@@
M`GB`F=\@_A$$)2`@`C__`!`0`*-G`````'1^,F8`````H($"-"T04@`0`*-G
M4("$WRV00P"@@0(T+1!1`"68``!09X1D!P``$"V(0P``````^!`3`"T0(@*0
M?D3<%`"`$!""F=\E*$`")<B``GSX$00!`',F]O]`$````````$.`\_]@$,B"
MF=\)^"`#)2!``*3^0!0E@$``^!`3`"T0(@*0?D3<\/^`%"4H0`(0@IG?#0`$
M)`GX(`-0@)#?6&<09B6(0`"A_@`04P`()%"`AM\P@9G?``"GW@``1-PE0$`"
MN&?&9`$`!20)^"`#)8@```;_`!`0`*-G>("9W^+]$000`*+_$`"BW\B"F=\)
M^"`#)2!``/S^`!`EB$``$+"@KM"!F=\E*```"?@@`R4@X`)V_T`0):!``#""
MF=\E($```@`&).[_!20)^"`#__\0//A_%6:@@0(T$`"C9RT050`MJ$,`^(*9
MWP8`!B0E**`""?@@`R4@@`*@@0(T$`"C9RT04``M$$,`^']#D`4`8!0P@IG?
M^7]#D$,`!"2%`&00`````"4P```E*```)2"``@GX(`/__Q`\@("9WV8'$03X
M?Q9F$`"C9R6H0`"@@0(T+1!6``4``!`ML$,``````"4HP`)^!Q$$)2"@`OB"
MF=\`@`8T)2C``@GX(`,E((`"`#`"`/;_P!R(@)G?"(&9WR4@@`()^"`#L'\0
M9J"!`C0M$%``$`"C9RV@0P"0@)G?)2B@`B4@@`+C!Q$$&``09J"!`C10@(??
M+1!0`!``HV<M@$,`*``59IAG]F0```````"(DO"`F=\E(``")3C``O__!B0!
M``4D"?@@`P(`$&;W_[`6`0"49O__`CR@@0,TR']*9"T88@`0`*)G+1!B`%"`
MB]]0@(??H($#-!``I&<M&&H`\("9WRU09`!`:6ME,&9I9B5`0`)H:.=D__\&
M)`$`!20E("`"\']`H`GX(`,`````4(""W]""F=\E($`"^"1"9`GX(`,8`*+_
M$`"BWQ@`N=\(9D1D"?@@`R4H(`)X@)G?7/T1!"4@(`)[_@`0$`"C9P````#;
M_@`0``"WWG1^I610@);?H($"-"T010`0`*-G+2A#`"7(@`+$]Q$$D&;$9G'_
M0!````````!"@&[_0!`P``,D;/]#$`$``B3G_@`0$+"BK@@`M=[<_J`2X(&9
MWPGX(`,E(*`"!`!#+-?^8!10@(7?"(.9W_S_0F1@:*5D"?@@`RT@H@+0_@`0
M"KBB`OI_19!!``0D>?^D%#""F=_[?T20=_^#%"4P``#\?T202``#)'/_@Q0`
M````_7]#D$4``B1O_V(4`````"4@@`("``8D"?@@`\;_!23X@IG?)2B@`B4@
M@`()^"`#*0`&)%"`B]]0@(??0&EK9?"`F=\E4*`",&9I9B5`0`)H:.=D__\&
M)`$`!22G_P`0)2`@`HB"F=\)^"`#`````+#_O6=``+S_`@`</"W@F0/@[IQG
M$`"P_W""D-](`+__,`"T_R@`L_\8`+'_.`"U_R``LO^X@I/?$(&9WP``!(X`
M`&+>!`"T9P@`HO\)^"`#````````!(X0@9G?"?@@`R6(0`"P`".24("1WU"`
MA-]@'S%F)2B``G!FA&0ER"`"8_<1!+$`0Z`$`$`0,0`#)```1("``(,0````
M`)B`F=\1^Q$$`````!"!F=\)^"`#```$CE"`A=\(@IG?`P`')`$`!B2@:*5D
M"?@@`R4@0``1`$`0)9!``!"!F=\)^"`#```$CA``0]Y0@(;?``!EW$B"F=\E
M($``"?@@`ZAHQF00`$+>``!"W`P`0HR`!4)\<P!`%!"!F=\0@9G?"?@@`P``
M!(Y0@(7?"(*9WP,`!R0!``8DL&BE9`GX(`,E($``$@!`$"600`!0@(3?)<@@
M`AAFA&0N]Q$$)2B``@``!(X0@9G?4@!`$"6H0``)^"`#`````!``0]Y(@IG?
M``!EW"4PH`()^"`#)2!`````!(X0@9G?"?@@`SB`E=\```2.$(&9WPGX(`,E
MD$``4("%W\B!F=\E($```0`&)`GX(`.X:*5D4("&WTB"F=\E*$``T&C&9`GX
M(`,E($`"$(&9WPGX(`,```2.4("$WR4H@`((9H1D)<@@`@7W$02Q`$"@)8!`
M`!@`0!!HPZ+^J(&9W\`!!20)^"`#)2```A$``R0$`$,0`0!#)`(`8RPU`&`0
M.("#WP@`H]\``&+>.0!B%$@`O]]``+S?.`"UWS``M-\H`+/?(`"RWQ@`L=\0
M`+#?"`#@`U``O6<X@(+?H("9W\O\$01PPT3<)8!``./_0!1HPZ+^4("$W\"!
MF=\)^"`#V&B$9``````!`$*`@O]`$)B`F=]^_P`0```````````)^"`#````
M`#B`@]\0`$+><,-CW%"`F=\``&7<N",Y9^7W$00``$3<K?\`$```!(X)^"`#
M```$CA``0]Z`@9G?``!EW`GX(`,E($``A_\`$!"!F=]0@(3?<,-CW,"!F=\`
M`&7<)3A``"4P``()^"`#`&F$9(B"F=\)^"`#`````,#_O6<P`+S_`@`</"W@
MF0.PZYQG(`"R_[B"DM\8`+'_$`"P_S@`O_\H`+/_J("9WP``0MXEB(``"`"B
M__;Y$00```````!#@`8`8!`E@$```0!"9"\`93@``$.`_/]@%`J`10`X@)/?
M__\#)!"P8HX5`$,04("$WP<`0!``````!0`@$@```````"*"'`!`%""!F=\`
M````"`"CWP``0MXO`&(4.`"_WS``O-\H`+/?(`"RWQ@`L=\0`+#?"`#@`T``
MO6<`````4("9WP0`I6=@'SEG@O81!)!FA&0>`$`0````````0H`;`$`0,``#
M)!D`0Q`!``(DX?\`$!"P8JY0@(7?!``&)*!GI60)^"`#)2```N#_0!0`````
M"`"CWP``0MX.`&(44("9WS@`O]\P`+S?*`"SWR``LM\0`+#?)2`@`A@`L=_8
M(#EGPO8`$$``O6<`````S_\`$!"P8*Z(@IG?"?@@`P``````````0/V]9[`"
MO/\"`!P\+>"9`T#JG&>X@HG?N`*__Z@"LO^@`K'_F`*P_P``(MT(`*-GB`*B
M_S@`B&1X`(UD)5!@`/\`##P````````'W0``!8T^,`<`/A('`#A>!@`^/@<`
M`/]","401P"@*`5\`_AG?3@R!@`"+"4`)1!'`"0PS``#^*5\)1!&``@`"&4`
M`$7]"`!"_>S_J!40`$IE``)H9&@`8MQ``&?<$`!FW```9=PF$$<`)A!&`"80
M10!X*`(`^A<"`"40H@`#^$)\@`!B_`@`8V3R_V@4"`"NWP``B]P0`(;<&`"'
MW`@`B-R"6@P\F7F,92``BMSZ'@L`>!$+`"400P`M<,P!)AC'`+IH"`"X+P@`
M)2BM`"UPR@$#^$)\)!AH``/XK7PF&&<`+1!.`!``KM\M$$,`)AC-``/X0GPD
M&&L`+7#,`2UPQP%XP0(`^LX"`"889@"Z@`L`N'\+`"T8;@`E<!D#)7CP`2T8
M;@`8`*[?)BBO``/X8WPD**(`+7#,`28HK0`M<,8!>,D#`/J&`P"XQP(`NA`"
M`"7``@,M$*X`)2@P`R``KM\M$$4`)BCX`0/X0GP#^.]]+7#,`20HHP`M:,T!
M>,D"`/J&`@`F**\`N'<#`+H8`P`E<,,!+2BM`"48,`,H`*W?+2BC`"88#@,#
M^*5\`_@8?R088@`M:*P!+6BO`7C)!0#ZA@4`)AAX`+A_`@"Z$`(`)7CB`2T8
M;0`E$#`#+1AB``/X;7PP`*/?)A#/`20010`#^,Y]+1AL`"T8>`!XR0T`^H8-
M`"803@`M$$,`)1@P`RT00P"XQP4`NB@%`"7`!0,#^$5\.`"BWR88^`$D&&T`
M`_CO?2T03``M$$X`>,D%`/J&!0`F&&\`+1AB`"40,`,M&&(`N'<-`+IH#0`E
M<,T!`_AM?$``H]\F$`X#)!!%``/X&'\M&&P`+1AO`'C)#0#ZA@T`)A!8`"T0
M0P`E&#`#+1!#`+A_!0"Z*`4`)7CE`0/X17Q(`*+?)AC/`208;0`#^,Y]+1!,
M`"T06`!XR04`^H8%`"88;@`M&&(`)1`P`RT88@"XQPT`NF@-`"7`#0,#^&U\
M4`"CWR80^`$D$$4``_CO?2T8;``M&&X`>,D-`/J&#0`F$$\`+1!#`"48,`,M
M$$,`N'<%`+HH!0`E<,4!`_A%?%@`HM\F&`X#)!AM``/X&'\M$$P`+1!/`'C)
M!0#ZA@4`)AAX`"T88@`E$#`#+1AB`+A_#0"Z:`T`)7CM`0/X;7Q@`*/?)A#/
M`20010`#^,Y]+1AL`"T8>`!XR0T`^H8-`"803@`M$$,`)1@P`RT00P"XQP4`
MNB@%`"7`!0,#^$5\:`"BWR88^`$D&&T``_CO?2T03``M$$X`>,D%`/J&!0`F
M&&\`+1AB`"40,`,M&&(`N'<-`+IH#0`E<,T!`_AM?'``H]\F$`X#)!!%``/X
M&'\M&&P`+1AO`'C)#0#ZA@T`)A!8`"T00P`E&#`#+1!#`+A_!0"Z*`4`)7CE
M`0/X17QX`*+?)AC/`208;0`#^,Y]+1!,`"T06`!XR04`^H8%`"88;@`M&&(`
M)1`P`RT88@"XQPT`NF@-`"7`#0,#^&U\@`"CWR80^`$D$$4``_CO?2T8;``M
M&&X`>,D-`/J&#0`F$$\`+1!#`"48,`,M$$,`N'<%`+HH!0`E<,4!`_A%?(@`
MHM\F&`X#)!AM``/X&'\M$$P`+1!/`'C)!0#ZA@4`)AAX`+A_#0"Z:`T`)7CM
M`2T88@"0`*W?)1`P`RT88@`F$,\!`_AC?`/XSGTD$$4`+6BL`2UHN`'ZS@,`
M)A!.`'C!`P`EP!D#+1!-`+AO!0"Z*`4`)6BE`9@`N=\M$%@``_A"?"8H[0$M
MR"P#^H8"``/X[WTD**,`>,$"`"UP+@,F**\`)<`0`RTHK@`#^!A_N'<#`+H8
M`P`E<,,!+2BX`*``N-\#^+E\)ABN`2W`#`,#^*U]^H89`"088@!X81D`+7@/
M`R88;0`E8)`!+1AO``/XC'VX?P(`NA`"`"W`;``E>.(!J`"LW]EN`SRAZV,T
M`_@0?R80SP'ZCA``)A!%`"U@@P%X*1``+6"-`24HL0`#^$)\+1!,``/XI7RX
M;QD`NL@9`"5HN0$M8$4`L`"BWP/XF7TF*.T!`_C1?2T00P`F<+@`^L89`'@I
M&0`M$%$``_C.?24HN``M$$X``_BE?+AW$`"Z@!``)7#0`2TH10"X`*+?`_BX
M?":`K@$#^/%]+1!#`"9X#`+ZAA@`>&$8`"T040`#^.]])6"0`2T03P`#^(Q]
MN'\9`+K(&0`E>/D!+6!,`,``HM\#^)E])H#/`0/XL7TM$$,`)F@%`OJ&&0!X
M*1D`+1!1``/XK7TE*+``+1!-``/XI7RX;Q@`NL`8`"5HN`$M*$4`R`"BWP/X
MN'PF@.T!`_C1?2T00P`F<`P"^H88`'AA&``M$%$``_C.?25@D`$M$$X``_B,
M?;AW&0"ZR!D`)7#9`2U@3`#0`*+?`_B9?2:`K@$#^/%]+1!#`"9X!0+ZAAD`
M>"D9`"T040`#^.]])2BP`"T03P`#^*5\N'\8`+K`&``E>/@!+2A%`-@`HM\#
M^+A\)H#/`0/XL7TM$$,`)F@,`OJ&&`!X81@`+1!1``/XK7TE8)`!+1!-``/X
MC'VX;QD`NL@9`"5HN0$M8$P`X`"BWP/XF7TF@.T!`_C1?2T00P`F<`4"^H89
M`'@I&0`M$%$``_C.?24HL``M$$X``_BE?+AW&`"ZP!@`)7#8`2TH10#H`*+?
M`_BX?":`K@$#^/%]+1!#`"9X#`+ZAA@`>&$8`"T040`#^.]])6"0`2T03P`#
M^(Q]N'\9`+K(&0`E>/D!+6!,`/``HM\#^)E])H#/`0/XL7TM$$,`)F@%`OJ&
M&0!X*1D`+1!1``/XK7TE*+``+1!-``/XI7RX;Q@`NL`8`"5HN`$M*$4`^`"B
MWP/XN'PF@.T!`_C1?2T00P`F<`P"^H88`'AA&``M$%$``_C.?25@D`$M$$X`
M`_B,?;AW&0"ZR!D`)7#9`2U@3````:+?`_B9?2:`K@$#^/%]+1!#`"9X!0+Z
MAAD`>"D9`"T040`#^.]])2BP`"T03P`#^*5\N'\8`+K`&``E>/@!+2A%``@!
MHM\#^+A\)H#/`0/XL7TM$$,`)F@,`OJ&&`!X81@`+1!1``/XK7TE8)`!+1!-
M``/XC'VX;QD`NL@9`"5HN0$M8$P`$`&BWP/XF7TF@.T!`_C1?2T00P`F<`4"
M^H89`'@I&0`M$%$``_C.?24HL``M$$X``_BE?+AW&`"ZP!@`)7#8`2TH10`8
M`:+?`_BX?":`K@$#^/%]+1!#`"9X#`+ZAA@`>&$8`"T040`#^.]])6"0`2T0
M3P`#^(Q]N'\9`+K(&0`E>/D!+6!,`"`!HM\#^)E])H#/`0/XL7TM$$,`)F@%
M`OJ&&0!X*1D`+1!1``/XK7TE*+``+1!-``/XI7RX;Q@`NL`8`"TH10`E:+@!
M*`&BWP/XL'PFP.T!`_C1?2T00P`F<`P#^L80`'AA$``M$%$``_C.?25@F`$M
M$$X``_B,?;AW&0"ZR!D`)7#9`2U@3``P`:+?`_B8?2;(K@'ZCA@`+1!#``/X
M[WTFR"4#>"D8`"T03P`#^#E_)2BQ`"T060"X?Q```_BE?+J`$``M*$4`)7CP
M`3@!HM\F@,\!`_BY?"T00P`#^*U])F`,`OJ.&0!X@1D`+1!-``/XC'VX;Q@`
M+1!,`+K`&``E8!$")6BX`2T03`!``:S?)H#M`0/X6'PM8(,!)A`%`@/XSGTM
M8(X!`_A"?/IV&`!X*1@`N!\9`"U@@@&ZR!D`QB,"/"48>0`E**X`2`&YWS?O
M0C2X$`(``_AN?"U@A0$E**,!`_B,?22`K@$D*+@`+<@B`P/X[WTMR"\#^HX,
M`"4HL`"X?Q@`>($,`+K`&``E>/@!+2BY`"7`$0(M*+@``_BX?%`!I=\E&&\`
M),CN`2THH@`D&&P``_BM?2UHK0#ZAA@`)1AY`+@O#`!XR1@`NF`,`"4HK``M
M&&T`)6`P`U@!N=\#^*U\+1AL`"5@Y0$#^&-\)(#M`21@F`$MR"(#+<@N`_J.
M`P`E8)`!N'<8`'B!`P"ZP!@`)7#8`2U@F0$EP!$"+6"8`0/XF'U@`:S?)2BN
M`"3(S0$#^.]])"BC`"U@@@$M8(\!N(<#`'AY&``E*+D`NA@#`/K.&``E&`,"
M+2BL`"5@^0%H`;G?`_AO?"THK``E8,,!`_BE?"2`SP$D8)@!+<@B`RW(+0/Z
MC@4`)6"0`;AO&`!X@04`NL`8`"5HN`$M8)D!)<`1`BU@F`$#^)A]<`&LWR48
M;0`DR*\!`_C.?20890`M8((!+6".`;B'!0!X<1@`)1AY`+HH!0#ZSA@`)2@%
M`BT8;``E8-D!>`&YWP/XKGPM&&P`)6"E`0/X8WPD@*X!)&"8`2W((@,MR"\#
M^HX#`"5@D`&X?Q@`>($#`+K`&``E>/@!+6"9`27`$0(M8)@!`_B8?8`!K-\E
M**\`),CN`0/XK7TD**,`+6""`2U@C0&XAP,`>&D8`"4HN0"Z&`,`^LX8`"48
M`P(M**P`)6"Y`8@!N=\#^&U\+2BL`"5@XP$#^*5\)(#M`21@F`$MR"(#+<@N
M`_J.!0`E8)`!N'<8`'B!!0"ZP!@`)7#8`2U@F0$EP!$"+6"8`0/XF'V0`:S?
M)1AN`"3(S0$#^.]])!AE`"U@@@$M8(\!N(<%`'AY&``E&'D`NB@%`/K.&``E
M*`4"+1AL`"5@^0&8`;G?`_BO?"T8;``E8,4!`_AC?"2`SP$D8)@!+<@B`RW(
M+0/ZC@,`)6"0`;AO&`!X@0,`NL`8`"5HN`$M8)D!)<`1`BU@F`$#^)A]H`&L
MWR4HK0`DR*\!`_C.?20HHP`M8((!+6".`;B'`P!X<1@`)2BY`+H8`P#ZSA@`
M)1@#`BTHK``E8-D!J`&YWP/X;GPM**P`)6"C`0/XI7PD@*X!)&"8`2W((@,M
MR"\#^HX%`"5@D`&X?Q@`>($%`+K`&``E>/@!+6"9`27`$0(M8)@!`_B8?;`!
MK-\E&&\`),CN`0/XK7TD&&4`+6""`2U@C0&XAP4`>&D8`"48>0"Z*`4`^LX8
M`"4H!0(M&&P`)6"Y`;@!N=\#^*U\+1AL`"5@Y0$#^&-\)(#M`21@F`$MR"(#
M+<@N`_J.`P`E8)`!N'<8`'B!`P"ZP!@`)7#8`2U@F0$EP!$"+6"8`0/XF7W`
M`:S?)2BN`"3`S0$#^.]])"BC`"U@@@$M8(\!N(<#`'AY&0`E*+@`NA@#`/K&
M&0`E&`,"+2BL`,@!L-\E8/@!+2BL``/X;WPE8,,!`_BE?"3`SP$D8)D!+8`"
M`BV`#0)XB04`^I8%`+IH&0`E8)@!N,<9`"7`#0,M8)`!)6@R`BU@C0'0`:W?
M)1AX``/XC'TDR`\#`_C.?20890`M:*(!+6BN`248>0!X<0P`^LX,`"T8;0`E
M:-D!N'<%`+HH!0`E*,4!V`&PWRT8;0`#^&-\`_BN?"5H!0,DD`X#+8`"`OJ.
M`P`D:*P!>,D#`"UX#P(E:+(!)<@Q`RUHKP$#^#E_N'\,`+I@#`#@`;#?)7CL
M`2UHN0$#^+E])2BO`"0HHP`DD.X!+8`"`OJ.&0`#^`Q_>,$9`"U@#`(E$+(`
M)2@1`[C'`P"Z&`,`+1!,`"7``P,#^*5\+2A%`"88^`$Q90(\)AAM`.M@0F3H
M`:W?>!`"``/XL'SZCA``+6BB`7AA$``M:*X!)6"1`0/X8WPM&&T``_B,?;AO
M&0"ZR!D`)6BY`2UP;`#P`:S?`_C9?288#0/ZCAD``_CO?28890`M8((!>"D9
M`"U@CP$E*+$``_AC?"T8;``#^*5\N&<0`+J`$``E8)`!+2AE`/@!H]\#^+!\
M)GBL`?J.$``M&&(``_@8?R9X[@%X<1``+1AX``/X[WTE<-$!+1AO``/XSGVX
M?QD`NL@9`"5X^0$MP&X```*CWP/X&7\F<(\!`_BQ?2T88@`F:,4!^G89`'@I
M&0`M&'$``_BM?24HK@`M&&T`N'<0``/XI7RZ@!``)7#0`2TH90`(`J/?`_BP
M?"9H[@$#^)%]+1AB`"9HN`%X81``^L80`"T8<0`#^*U])6"8`2T8;0`#^(Q]
MN&\9`+K(&0`E:+D!+6!L`!`"H]\#^)A])LC-`0/X\7TM&&(`)G@E`_K.&`!X
M*1@`+1AQ``/X[WTE*+D`+1AO``/XI7RX?Q``NH`0`"5X\`$M*&4`&`*CWP/X
MN7PF@*\!`_C1?2T88@`F<`P"^H89`'AA&0`M&'$``_C.?25@D`$M&&X``_B,
M?;AW&`"ZP!@`)7#8`2U@;``@`J/?`_B8?2:`[@$#^+%]+1AB`"9H!0+ZAA@`
M>"D8`"T8<0`#^*U])2BP`"T8;0`#^*5\N&\9`+K(&0`E:+D!+2AE`"@"H]\#
M^+E\)H#-`0/X\7TM&&(`)G@,`OJ&&0!X81D`+1AQ``/X[WTE8)`!+1AO``/X
MC'VX?Q@`NL`8`"5X^`$M8&P`,`*CWP/XF'TF@*\!`_C1?2T88@`F<`4"^H88
M`'@I&``M&'$``_C.?24HL``M&&X``_BE?+AW&0"ZR!D`)7#9`2TH90`X`J/?
M`_BY?":`[@$#^+%]+1AB`"9H#`+ZAAD`>&$9`"T8<0`#^*U])6"0`2T8;0`#
M^(Q]N&\8`+K`&``E:+@!+6!L`$`"H]\#^)A])H#-`0/X\7TM&&(`)G@%`OJ&
M&`!X*1@`+1AQ``/X[WTE*+``+1AO``/XI7RX?QD`NL@9`"5X^0$M*&4`2`*C
MWP/XN7PF@*\!`_C1?2T88@`F<`P"^H89`'AA&0`M&'$``_C.?25@D`$M&&X`
M`_B,?;AW&`"ZP!@`)7#8`2U@;`!0`J/?`_B8?2:`[@$#^+%]+1AB`"9H!0+Z
MAA@`>"D8`"T8<0`#^*U])2BP`"T8;0`#^*5\N&\9`+K(&0`E:+D!+2AE`%@"
MH]\#^+!\)LC-`0/X\7TM&&(`)G@L`_K.$`!X81``+1AQ``/X[WTE8)D!+1AO
M``/XC'VX?Q@`NL`8`"5X^`$M8&P`8`*CWP/XF'TFR*\!`_C1?2T88@`F<"4#
M^LX8`'@I&``M&'$``_C.?24HN0`M&&X`N,\0``/XI7RZ@!``)<@P`RTH90!H
M`J/?`_BQ?"9P^0$#^+!]+1AB`"9HS`'Z=A$`>&$1`"T8<``#^*U])6".`2T8
M;0`#^(Q]N'<8`+K`&``M:&P`)7#8`7`"H]\#^+!])F`N`R9@A0'ZQA``+1AB
M``/X[WUX*1``+1AO`"4HN``#^(]]+1AO`+AG$0`#^*5\NH@1`"5@D0$MP&4`
M>`*EWR88S`$#^`]_+2BB``/X.7\F&&T`+2BY``/X8WQXR0\`^HX/`"THHP`E
M&#$#N&\0`"THHP"Z@!``@`*CWR5HL`$M$&(`)AB-`0/XI7PM$$L``_C.?288
M>`!X604`+1!.``/X8WSZ=@4`+1!#`"48;@$M$$,``_A"?+@?#P"Z>`\```""
M_"48;P`M&&8`B`*KWRTPIP$M**@`+1"*`0``)]T#^*5\`_AC?`/XQGP#^$)\
M"`"%_!``@_P8`(;\"`!G%2``@ORX`K_?L`*\WZ@"LM^@`K'?F`*PWP@`X`/`
M`KUGB(*9WPGX(`,`````\/^]9P``O/\"`!P\+>"9`]C3G&<0@IG?"`"__PGX
M(`.```0D74P%/']NI61X*`4`YW<&)#T,!#P0`$7\16<'/'@T!@`R$`4\'RZ$
M9`$CYV2)J\9D=E2E9#@A!````$?\"`!&_!@`1?P@`$3\*`!`_#``0/QX`$"L
M"`"_WP``O-\(`.`#$`"]9[#_O6=``+S_.`"V_S``M?\0`+'_2`"__R@`M/\@
M`+/_&`"R_P@`L/\H`(/<^!`&`"T00P`"`!P\`_A"?"W@F0,K&$,`):C``%#3
MG&<P`(;<);"```(`8!`EB*```0#&9'H?%0!X`,2.+1AF`"@`POXP`,/^1`"`
M%#@`T&9``*(J5P!`%%"`E-_`_[4F@\FR?@$`4V:XF1,`+9@S`O!%E&8'`"1J
M#P`I:@``)&X7`"AJ'P`G:B<`)FHO`"5J-P`C:C\`(FH(`"EN$``H;A@`)VX@
M`"9N*``E;C``(VXX`")N!P`$L@``!+8/``FR"``)MA<`"+(0``BV'P`'LA@`
M![8G``:R(``&MB\`!;(H``6V-P`#LC```[8E(,`"/P`"LB7(@`(X``*V^?D1
M!$``,6;;_S,6`````("1$@`CJ+("P(*9WR4PH`(E*&`""?@@`R4@``)X`-6N
M2`"_WT``O-\X`+;?,`"UWR@`M-\@`+/?&`"RWQ``L=\(`+#?"`#@`U``O6<`
M````0``4)",0A`(J&*(""Q"C`L""F=\E,$``)2@@`BT@!`()^"`#)9A``'@`
MPHXA$%,`Y_]4%'@`PJY0@)3?)2#``O!%E&8ER(`"S_D1!".HLP*H_P`0+8@S
M`M?_`!`EF"`"P/^]9S``O/\H`+7_&`"S_Q``LO\(`+'_``"P_S@`O_\@`+3_
M*`"BW"@`HXPE@*``,`"EC,,H0GP"`!P\H!@#?`$`1B0MX)D#.``59@(<(P"@
M*`5\:-&<9P(L)0`M$*(")9!@`#D`QRB`_P,D)8B``+"!F=\EF*````!#H%@`
MX!0M(*8"0``")%"`E-\C,$8`)2@```GX(`/P191F)<B``J'Y$00E(``"L(&9
MWS@`!B0E*```"?@@`R4@H`(E(``")<B``G``$ZZ7^1$$=``2K@```M[0@IG?
M.A8"````(J(```+>)2```CH4`@`!`"*B```"WCH2`@`"`"*B```"W@,`(J((
M``+>.A8"``0`(J((``+>.A0"``4`(J((``+>.A("``8`(J((``+>!P`BHA``
M`MXZ%@(`"``BHA```MXZ%`(`"0`BHA```MXZ$@(`"@`BHA```MX+`"*B&``"
MWCH6`@`,`"*B&``"WCH4`@`-`"*B&``"WCH2`@`.`"*B&``"W@\`(J(@``+>
M.A8"`!``(J(@``+>.A0"`!$`(J(@``+>.A("`!(`(J(@``+>"?@@`Q,`(J(X
M`+_?,`"\WR@`M=\@`+3?&`"SWQ``LM\(`+'?``"PWP@`X`-``+UG.``")%"`
ME-\C,$8`)2@```GX(`/P191FL?\`$"4@``(``````````,#_O6<P`+S_`@`<
M/"W@F0-@SYQG$`"R_P``L/_(@)+?T("0W]B`F=\OD%`"*`"U_R``M/\8`+/_
M.`"__P@`L?_[D!(`)9B``"6@H`!N[A$$):C```H`0!(EB```````````&=XE
M,*`")2B``B4@8`()^"`#`0`Q9OG_418(`!!F.`"_WS``O-\H`+7?(`"TWQ@`
ML]\0`++?"`"QWP``L-\(`.`#0`"]9P@`X`,`````\/^]9P``O/\"`!P\+>"9
M`[#.G&=(@(+?.(*9WP``1]P(`+__"?@@`P`````(`+_?``"\WP@`X`,0`+UG
M`````!"`F=\E>.`#"?@@`V@`&&00@)G?)7C@`PGX(`-G`!AD$("9WR5XX`,)
M^"`#90`89!"`F=\E>.`#"?@@`V,`&&00@)G?)7C@`PGX(`-A`!AD$("9WR5X
MX`,)^"`#8``89!"`F=\E>.`#"?@@`U\`&&00@)G?)7C@`PGX(`->`!AD$("9
MWR5XX`,)^"`#6P`89!"`F=\E>.`#"?@@`UH`&&00@)G?)7C@`PGX(`-9`!AD
M$("9WR5XX`,)^"`#6``89!"`F=\E>.`#"?@@`U<`&&00@)G?)7C@`PGX(`-6
M`!AD$("9WR5XX`,)^"`#50`89!"`F=\E>.`#"?@@`U,`&&00@)G?)7C@`PGX
M(`-2`!AD$("9WR5XX`,)^"`#4``89!"`F=\E>.`#"?@@`T\`&&00@)G?)7C@
M`PGX(`-.`!AD$("9WR5XX`,)^"`#30`89!"`F=\E>.`#"?@@`TP`&&00@)G?
M)7C@`PGX(`-+`!AD$("9WR5XX`,)^"`#2@`89!"`F=\E>.`#"?@@`TD`&&00
M@)G?)7C@`PGX(`-(`!AD$("9WR5XX`,)^"`#1P`89!"`F=\E>.`#"?@@`T4`
M&&00@)G?)7C@`PGX(`-$`!AD$("9WR5XX`,)^"`#0P`89!"`F=\E>.`#"?@@
M`T(`&&00@)G?)7C@`PGX(`-!`!AD$("9WR5XX`,)^"`#0``89!"`F=\E>.`#
M"?@@`S\`&&00@)G?)7C@`PGX(`,^`!AD$("9WR5XX`,)^"`#/0`89!"`F=\E
M>.`#"?@@`SP`&&00@)G?)7C@`PGX(`,[`!AD$("9WR5XX`,)^"`#.0`89!"`
MF=\E>.`#"?@@`S@`&&00@)G?)7C@`PGX(`,W`!AD$("9WR5XX`,)^"`#-@`8
M9!"`F=\E>.`#"?@@`S4`&&00@)G?)7C@`PGX(`,T`!AD$("9WR5XX`,)^"`#
M,P`89!"`F=\E>.`#"?@@`S(`&&00@)G?)7C@`PGX(`,Q`!AD$("9WR5XX`,)
M^"`#+P`89!"`F=\E>.`#"?@@`RX`&&00@)G?)7C@`PGX(`,M`!AD$("9WR5X
MX`,)^"`#+``89!"`F=\E>.`#"?@@`RH`&&00@)G?)7C@`PGX(`,H`!AD$("9
MWR5XX`,)^"`#)P`89!"`F=\E>.`#"?@@`R8`&&00@)G?)7C@`PGX(`,E`!AD
M$("9WR5XX`,)^"`#)``89`````````````````````#P_[UG``"\_P(`'#PM
MX)D#"`"__]#*G&<(`+_?``"\WP@`X`,0`+UG```````````!``(``````"5S
M+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO
M861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O
M8R\E:2\E<P``````+@````````!005)?5$5-4```````````4$%27U!23T=.
M04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"````````
M``!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$14)5
M1P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````
M````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@```````%!!
M4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%
M04X]````````,0````````!,1%],24)205)97U!!5$@`55-%4@````!365-4
M14T``"]T;7``````5$U01$E2``!414U01$E2`%1%35``````5$U0``````!5
M4T523D%-10``````````)3`R>`````!P87(M`````"5S)7,E<R5S````````
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R;``````N<&%R`````"5S
M)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E
M<P``````````&`````````!P97)L`````#``````````4$%2.CI086-K97(Z
M.E9%4E-)3TX`````,2XP-30```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64`
M```````M+0```````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL
M96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM
M;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E
M=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE
M;F%M95TI.PI]"GT@?0I"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<
M;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N
M86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R
M+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;
M7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*
M;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D[
M"FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI-04=)0SH@>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ
M<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I
M;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@
M<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R!?1D@["FUY
M("1M86=I8U]P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H=6YK7W-I>F4[(",@
M3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE
M"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P
M;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!
M1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I
M8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*:68@*"1M86=I8U]P;W,@/"`P*2![
M"F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B
M(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IS965K(%]&
M2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*
M)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D
M97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ<5M.
M;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G
M;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!
M4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I
M<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*
M=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R
M"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H
M:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8[
M"GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?
M:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB
M<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H
M($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@
M(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?
M87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*
M96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF
M("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E
M<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P
M96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@
M9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?
M;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN
M8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@
M0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]
M"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@
M<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I
M.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B
M73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H
M6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D
M('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U
M9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T
M:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&
M:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&
M:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T
M92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L
M(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR
M96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N
M97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@
M)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D
M<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^
M('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T
M:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H
M($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L
M:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@
M*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y
M?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I
M<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL
M87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2![
M"FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG
M($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F
M:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\
M96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D
M;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@
M;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L
M;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H
M)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A
M:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T
M("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?
M1$5"54=].PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@
M)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R
M>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@
M=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF
M:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92)=*3L*)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?
M+V<["FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII
M9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R
M;V=N86UE*2E;.5TI('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PIS965K
M("1F:"P@+3$X+"`R.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@-CL*:68@
M*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G)E860@
M)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U]8V%C:&4M)&)U9B(["GT*96QS92!["FUY("1D:6=E<W0@
M/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z.E-(03L*;7D@)&-T>"`]($1I9V5S
M=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*)&-T
M>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0[
M"GT@?'P@)&UT:6UE.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]8V%C:&4M
M)&1I9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%
M04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?71E;7`M)"0B.PI]
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64@;W(@9&EE('%Q6T-A;B=T('=R:71E
M("(D=&5M<&YA;64B.B`D(5T["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E
M("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A
M;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I
M*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,
M14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH```!?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@(```````````<&5R;'AS:2YC````````````````````
M+VQI8C8T+VQD+G-O+C$`````````````.!\```````#('@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````_____P```````````````%AI
M````````````````````````````````````````````````````````````
M@"`;````````T&````````!X80```````````@``````.+`!``````!(LP$`
M```````````````````!``````!000```````)@H````````N"D```````"(
M-0```````%A<````````X%P```````#(7@```````#@N````````\#8`````
M``"8+````````(!A````````(+`!``````"`1````````!"F`0``````"*8!
M``````#8&@````````````````````````````!`90```````#!E````````
M(&4````````090````````!E``````````````````#P9```````````````
M````X&0```````#09````````,!D````````L&0``````````````````*!D
M````````D&0```````"`9````````'!D````````8&0```````!09```````
M`$!D````````,&0````````@9```````````````````$&0`````````9```
M`````/!C````````X&,```````#08P```````,!C````````L&,```````"@
M8P```````)!C````````@&,```````!P8P``````````````````8&,`````
M``!08P```````$!C````````,&,````````@8P```````!!C`````````&,`
M``````#P8@```````.!B````````T&(``````````````````,!B````````
ML&(``````````````````*!B````````D&(```````"`8@```````'!B````
M````8&(```````!08@```````$!B`````````````````````````````#!B
M````````(&(````````08@````````!B``````````````````#P80``````
M````````````X&$``````````````````-!A````````P&$```````!(LP$`
M`````$=#0SH@*$1E8FEA;B`Q,2XR+C`M,30I(#$Q+C(N,```8!\`````?Y#X
M____``````````!0````'0```!\```#8(`````#_D/C___\``````````$`!
M```=````'P`````C``````.0^/___P````````````$``!T````?````N",`
M````'Y#X____``````````!0$```'0```!\```#X)`````#_D/C___\`````
M`````&`````=````'P```*`G``````&0^/___P``````````(````!T````?
M````0"@``````)#X____```````````0````'0```!\```"8*``````/D/C_
M__\``````````&`@```=````'P```*`I````````````````````````````
M`!T````?````N"D`````_]#X____``````````!@$0``'0```!\```!H+```
M```````````````````````````=````'P```)@L``````.0^/___P``````
M````(````!T````?````."X`````_]#X____``````````"@````'0```!\`
M``"(-``````#D/C___\``````````#`````=````'P```$`U``````"0^/__
M_P``````````$````!T````?````B#4`````'Y#X____``````````!0````
M'0```!\```#P-@````#_T/C___\``````````!""```=````'P```%!!````
M`#^0^/___P``````````4````!T````?````@$0`````#Y#X____````````
M``!`````'0```!\````@&P`````_D/C___\``````````'`````=````'P``
M`/!%``````>0^/___P``````````P`(``!T````?````6%P``````)#X____
M```````````0````'0```!\```#@7`````!_D/C___\``````````%`````=
M````'P```,A>`````#^0^/___P``````````0````!T````?````T&``````
M/Y#X____``````````!`````'0```!\```!X80``````````````````````
M```````=````'P```(!A``````"0^/___P``````````$````!T````?````
M00\```!G;G4``0<````$`0`N<VAS=')T86(`+DU)4%,N86)I9FQA9W,`+DU)
M4%,N;W!T:6]N<P`N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N
M9'EN86UI8P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YI;FET`"YT97AT`"Y-25!3+G-T=6)S
M`"YF:6YI`"YR;V1A=&$`+FEN=&5R<``N96A?9G)A;64`+FEN:71?87)R87D`
M+F9I;FE?87)R87D`+F1A=&$`+G)L9%]M87``+F=O=``N<V1A=&$`+F)S<P`N
M8V]M;65N=``N<&1R`"YG;G4N871T<FEB=71E<P``````````````````````
M````````````````````````````````````````````````````````````
M```````````+````*@``<`(`````````<`(```````!P`@```````!@`````
M```````````````(`````````!@`````````&@````T``'`"```(`````(@"
M````````B`(```````"X`0``````````````````"``````````!````````
M`"@````'`````@````````!`!````````$`$````````)```````````````
M``````0````````````````````[````!P````(`````````9`0```````!D
M!````````"`````````````````````$````````````````````20````8`
M```"`````````(@$````````B`0```````!P`@````````@`````````"```
M```````0`````````%(````%`````@````````#X!@```````/@&````````
M,`,````````'``````````@`````````!`````````!8````"P````(`````
M````*`H````````H"@```````-@)````````"`````(````(`````````!@`
M````````8`````,````"```````````4`````````!0```````#P!```````
M`````````````0```````````````````&@```#___]O`@````````#P&```
M`````/`8````````T@`````````'``````````(``````````@````````!U
M````_O__;P(`````````R!D```````#(&0```````,``````````"`````,`
M```(````````````````````A`````D````"`````````(@:````````B!H`
M``````!0``````````<`````````"``````````0`````````(T````!````
M!@````````#8&@```````-@:````````0`````````````````````0`````
M``````````````"3`````0````8`````````(!L````````@&P```````*!&
M```````````````````0````````````````````F0````$````&````````
M`,!A````````P&$```````"@`P``````````````````"```````````````
M`````*4````!````!@````````!@90```````&!E````````*```````````
M``````````0```````````````````"K`````0````(`````````D&4`````
M``"090```````&!````````````````````0````````````````````LP``
M``$````"`````````/"E````````\*4````````/````````````````````
M`0```````````````````+L````!`````@``````````I@````````"F````
M````!`````````````````````0```````````````````#%````#@````,`
M````````"*8!```````(I@````````@````````````````````(````````
M``@`````````T0````\````#`````````!"F`0``````$*8````````(````
M````````````````"``````````(`````````-T````!`````P``````````
ML`$```````"P````````,````````````````````!``````````````````
M``#C`````0````,`````````,+`!```````PL`````````@`````````````
M```````(````````````````````[`````$````#```0`````$"P`0``````
M0+`````````(`P``````````````````$``````````(`````````/$````!
M`````P``$`````!(LP$``````$BS````````"`````````````````````@`
M``````````````````#X````"`````,`````````4+,!``````!0LP``````
M`#`0```````````````````0````````````````````_0````$````P````
M````````````````4+,````````?`````````````````````0`````````!
M``````````8!```!`````````````````````````'"S````````8`,`````
M``````````````0````````````````````+`0``]?__;P``````````````
M``````#0M@```````!`````````````````````!````````````````````
M`0````,`````````````````````````X+8````````;`0``````````````
3`````0``````````````````````
